==> cyphesis-snapshot-1999.01.15.tar.gz: cyphesis/thing.py <==
""" thing.py
 Copyright (C) 1998 Aloril
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""

from copy import copy

import util,const
from event import *

PlaceError="PlaceError"

class thing:
    "thing: (=base class npc,tools, etc)"
    is_thing=1
    def __init__(self, name, desc='some thing', place='home', status=1.0,
                 age=0.0, xyz=None):
        self.name=name
        self.__doc__=desc
        self.place=place
        self.status=status
        self.age=age #in seconds
        self.xyz=xyz #coordinates
        self.id=self.name
        self.event_dict={}
    def destroy(self): pass
    def str(self):
        s="name: "+str(self.name)
        s=s+", id: "+str(self.id)
        s=s+", description: "+str(self.__doc__)
        s=s+", place: "+str(self.place)
        s=s+", xyz: "+str(self.xyz)
        s=s+", status: "+str(self.status)
        s=s+", age: "+str(self.age)
        return s
    def __str__(self):
        return "<Thing: "+self.str()+">\n"
    def __repr__(self):
        return `self.id`
    def get_xyz(self):
        try:
            return self.place.get_xyz()
        except AttributeError:
            return self.xyz
    def get_loc(self):
        if self.xyz: return self.xyz
        return self.place
    def get_type(self):
        return util.get_derivation_string(self.__class__)
    #event handling: 
    #e is current input event
    #may return new events
    def move_event(self,e):
        target=e.loc
        if target==self:
            raise PlaceError, `self`
        #if its part of inventory, use its xyz
        if hasattr(target,"xyz"):
            self.xyz=None
            self.place=target
        else:
            self.xyz=target
            self.place=None
        return [event("sight",what=e)]
    def change_event(self,e):
        t=e.what
        t.status=t.status+e.amount
        if t.status<=const.fzero:
            return [event("destroy", what=t)]
        return [event("sight",what=e)]
    def undefined_event(self,e):
        #print "Unknown event:", e.command
        pass
    def analyse_event(self,e):
        "e is current input event"
        return get_event_func(self,e)(e)
    def analyse_input(self, input):
        output=[]
        for e in input:
            res=self.analyse_event(e)
            if res:
                for o in res:
                    output.append(o)
        return output
    def run_step(self,time,input):
        return self.analyse_input(input)

==> cyphesis-snapshot-1999.02.13.tar.gz: cyphesis/thing.py <==
""" thing.py
 Copyright (C) 1998 Aloril
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""

from copy import copy

import const
from event import *
from misc import *

PlaceError="PlaceError"

class thing:
    "thing: (=base class npc,tools, etc)"
    is_thing=1
    def __init__(self, **kw):
        self.attributes=["id","type"]
        set_kw(self,kw,"name",'Foo')
        set_kw(self,kw,"desc",'some thing')
        set_kw(self,kw,"place",'home')
        set_kw(self,kw,"status",1.0)
        set_kw(self,kw,"age",0.0) #in seconds
        set_kw(self,kw,"xyz") #coordinates
        self.id=self.name
        self.type=self.get_type()
        self.event_dict={}
    def destroy(self): pass
    def str(self):
        s="name: "+str(self.name)
        s=s+", id: "+str(self.id)
        s=s+", description: "+str(self.desc)
        s=s+", place: "+str(self.place)
        s=s+", xyz: "+str(self.xyz)
        s=s+", status: "+str(self.status)
        s=s+", age: "+str(self.age)
        return s
    def __str__(self):
        return "<Thing: "+self.str()+">\n"
    def __repr__(self):
        return `self.id`
    def get_xyz(self):
        try:
            return self.place.get_xyz()
        except AttributeError:
            return self.xyz
    def get_loc(self):
        if self.xyz: return self.xyz
        return self.place
    def get_type(self):
        return get_derivation_string(self.__class__)
    def get_short_type(self):
        return self.__class__.__name__
    def get_ething(self):
        d={}
        for a in self.attributes[1:]:
            d[a]=getattr(self,a)
        return apply(ething,(self.id,),d)
    #event handling: 
    #e is current input event
    #may return new events
    def move_event(self,e):
        target=e.loc
        if target==self:
            raise PlaceError, `self`
        #if its part of inventory, use its xyz
        if hasattr(target,"xyz"):
            self.xyz=None
            self.place=target
        else:
            self.xyz=target
            self.place=None
        return [event("sight",what=e)]
    def change_event(self,e):
        t=e.what
        t.status=t.status+e.amount
        if t.status<=const.fzero:
            return [event("destroy", what=t)]
        return [event("sight",what=e)]
    def look_event(self,e):
        a=e.what
        if type(a)==StringType and a[0]!="_":
            if a in self.attributes:
                return [event("sight",what=a,amount=getattr(self,a))]
            else:
                return [event("illegal",what=e,desc="AttributeError")]
        else:
            return [event("sight",what=self.get_ething())]
    def undefined_event(self,e):
        #print "Unknown event:", e.command
        pass
    def analyse_event(self,e):
        "e is current input event"
        return get_event_func(self,e)(e)
    def analyse_input(self, input):
        output=[]
        for e in input:
            res=self.analyse_event(e)
            if res:
                for o in res:
                    output.append(o)
        return output
    def run_step(self,time,input):
        return self.analyse_input(input)
